@@ -29,7 +29,8 @@ for job_info in jobs_list:
             print(f.type)
 """
 
-jediTaskID = 10517 # 10607
+jediTaskID = 10517    # 10607
+jediTaskID = 10607
 ret = Client.getJediTaskDetails({'jediTaskID': jediTaskID}, True, True, verbose=False)
 print(ret)
 
@@ -41,6 +42,24 @@ jobids = task_info['PandaID']
 ret = Client.getJobStatus(ids=jobids, verbose=False)
 print(ret)
 
+if ret[0] == 0:
+    jobs = ret[1]
+    left_jobids = []
+    ret_jobs = []
+    print(len(jobs))
+    for jobid, jobinfo in zip(jobids, jobs):
+        if jobinfo is None:
+            left_jobids.append(jobid)
+        else:
+            ret_jobs.append(jobinfo)
+    if left_jobids:
+        print(len(left_jobids))
+        ret = Client.getFullJobStatus(ids=left_jobids, verbose=False)
+        print(ret)
+        print(len(ret[1]))
+    ret_jobs = ret_jobs + ret[1]
+    print(len(ret_jobs))
+
 sys.exit(0)
 
 """
